Module blaxel.core.client.models.update_workspace_service_account_body
======================================================================

Classes
-------

`UpdateWorkspaceServiceAccountBody(description: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Attributes:
        description (Union[Unset, str]): Service account description
        name (Union[Unset, str]): Service account name
    
    Method generated by attrs for class UpdateWorkspaceServiceAccountBody.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `description: blaxel.core.client.types.Unset | str`
    :

    `name: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :